<?php
/**
* 2007-2019 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2019 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

class EasycreditratenkaufRedirectModuleFrontController extends ModuleFrontController
{

    use EasycreditRedirectionTrait;

    public function postProcess()
    {
        $ecRequest = new Patworx\Easycreditratenkauf\Struct\Transaction();

        $customersInvoiceAddress = new Address(
            (int)Context::getContext()->cart->id_address_invoice
        );
        $customerShippingAddress = new Address(
            (int)Context::getContext()->cart->id_address_delivery
        );

        $invoiceAddress = new Patworx\Easycreditratenkauf\Struct\InvoiceAddress(
            [
                'address' => $customersInvoiceAddress->address1,
                'additionalAddressInformation' => $customersInvoiceAddress->address2,
                'zip' => $customersInvoiceAddress->postcode,
                'city' => $customersInvoiceAddress->city,
                'country' => Country::getIsoById((int)$customersInvoiceAddress->id_country),
                'firstName' => $customersInvoiceAddress->firstname,
                'lastName' => $customersInvoiceAddress->lastname
            ]
        );
        $shippingAddress = new Patworx\Easycreditratenkauf\Struct\ShippingAddress(
            [
                'address' => $customerShippingAddress->address1,
                'additionalAddressInformation' => $customerShippingAddress->address2,
                'zip' => $customerShippingAddress->postcode,
                'city' => $customerShippingAddress->city,
                'country' => Country::getIsoById((int)$customerShippingAddress->id_country),
                'firstName' => $customerShippingAddress->firstname,
                'lastName' => $customerShippingAddress->lastname
            ]
        );

        $shoppingCartInformationItems = [];
        foreach (Context::getContext()->cart->getProducts() as $product) {
            $product_default_category = new Category((int)$product['id_category_default']);

            $shoppingCartInformationItem = new Patworx\Easycreditratenkauf\Struct\ShoppingCartInformationItem(
                [
                    'productName' => $product['name'],
                    'quantity' => $product['quantity'],
                    'price' => $product['price_wt'],
                    'manufacturer' => $product['manufacturer_name'],
                    'productCategory' => $product_default_category->getName(
                        (int)Context::getContext()->language->id
                    ),
                    'articleNumber' => [
                        new Patworx\Easycreditratenkauf\Struct\ArticleNumberItem(
                            [
                                'numberType' => 'Articlenumber',
                                'number' => $product['reference']
                            ]
                        )
                    ]
                ]
            );
            $shoppingCartInformationItems[] = $shoppingCartInformationItem;
        }

        $ecRequest->orderDetails = new Patworx\Easycreditratenkauf\Struct\OrderDetails(
            [
                'orderValue' => (float)Context::getContext()->cart->getOrderTotal(true),
                'numberOfProductsInShoppingCart' => Context::getContext()->cart->nbProducts(),
                'invoiceAddress' => $invoiceAddress,
                'shippingAddress' => $shippingAddress,
                'shoppingCartInformation' => $shoppingCartInformationItems
            ]
        );

        $ecRequest->shopsystem = new Patworx\Easycreditratenkauf\Struct\Shopsystem(
            [
                'shopSystemManufacturer' => 'PrestaShop ' . _PS_VERSION_,
                'shopSystemModuleVersion' => $this->module->version
            ]
        );

        $customer = new Customer((int)Context::getContext()->customer->id);
        $ecRequest->customer = new Patworx\Easycreditratenkauf\Struct\Customer(
            [
                'gender' => Patworx\Easycreditratenkauf\Struct\Customer::getGenderString($customer->id_gender),
                'firstName' => Tools::substr($customer->firstname, 0, 27),
                'lastName' => Tools::substr($customer->lastname, 0, 27),
                'contact' => new Patworx\Easycreditratenkauf\Struct\Contact(
                    [
                        'email' => $customer->email,
                        'mobilePhoneNumber' => $customersInvoiceAddress->phone_mobile,
                        'phoneNumber' => $customersInvoiceAddress->phone
                    ]
                )
            ]
        );

        if ($customer->birthday && '0000-00-00' != $customer->birthday) {
            $ecRequest->customer->birthDate = date("Y-m-d", strtotime($customer->birthday));
        }

        $carrier = new Carrier(Context::getContext()->cart->id_carrier);

        $ecRequest->customerRelationship = new Patworx\Easycreditratenkauf\Struct\CustomerRelationship(
            [
                'customerStatus' => $customer->isGuest() ? 'NEW_CUSTOMER' : 'EXISTING_CUSTOMER',
                'customerSince' => date("Y-m-d", strtotime($customer->date_add)),
                'orderDoneWithLogin' => $customer->isGuest() ? false : true,
                'numberOfOrders' => sizeof(Order::getCustomerOrders((int)$customer->id)),
                'logisticsServiceProvider' => $carrier->name
            ]
        );

        $urlSuccess = Context::getContext()->link->getModuleLink(
            $this->module->name,
            'process'
        );
        $urlCancellation = Context::getContext()->link->getModuleLink(
            $this->module->name,
            'cancel'
        );
        $urlDenial = Context::getContext()->link->getModuleLink(
            $this->module->name,
            'denied'
        );

        $ecRequest->redirectLinks = new Patworx\Easycreditratenkauf\Struct\RedirectLinks(
            [
                'urlSuccess' => $urlSuccess,
                'urlCancellation' => $urlCancellation,
                'urlDenial' => $urlDenial
            ]
        );

        $ecRequest->prepare();

        $initRequestResponse = EasycreditClient::getInstance()->initTransaction(
            json_encode($ecRequest)
        );

        $initRequestResponseRaw = $initRequestResponse;
        $initRequestResponse = json_decode($initRequestResponse, true);

        $log = new EasycreditLog();
        $log->ps_cart_id = (int)Context::getContext()->cart->id;
        $log->ps_customer_id = (int)Context::getContext()->customer->id;
        $log->url = EasycreditClient::$endpoints['transaction']['url'];
        if (isset($initRequestResponse['technicalTransactionId'])) {
            $log->easycredit_vorgang = $initRequestResponse['technicalTransactionId'];
        }
        $log->request = json_encode($ecRequest);
        $log->response = $initRequestResponseRaw;
        $log->save();

        if (isset($initRequestResponse['technicalTransactionId'])) {
            EasycreditSession::getInstance()->set(
                'technicalTransactionId',
                $initRequestResponse['technicalTransactionId']
            );
        }
        if (isset($initRequestResponse['transactionId'])) {
            EasycreditSession::getInstance()->set(
                'transactionId',
                $initRequestResponse['transactionId']
            );
        }
        if (isset($initRequestResponse['deviceIdentToken'])) {
            EasycreditSession::getInstance()->set(
                'deviceIdentToken',
                $initRequestResponse['deviceIdentToken']
            );
        }

        if (isset($initRequestResponse['redirectUrl'])) {
            Tools::redirect(
                $initRequestResponse['redirectUrl']
            );
        }

        $this->errorRedirect();
    }
}
